@@ -27,8 +27,8 @@ def _commit(cls):
     cursor.connection.commit()
 
 def _key_by_table(db, table, cursor):
-    db = db.dbcnf['db']
-    db_table = '%s.%s'%(db , table)
+    db = db._config
+    db_table = '%s:%s'%(db , table)
     key = [ db_table ]
 
     if cursor.description:
