@@ -23,8 +23,11 @@ class RedisKey(object):
     def __call__(self, attr, name=''):
         key = attr+name
         redis = self.redis
+
         if key in _EXIST:
-            raise Exception('redis key is already defined %s'%key)
+            print 'REDIS KEY IS ALREADY DEFINED %s !!!'%key
+
+
         _EXIST.add(key)
         if redis:
             _key = redis.hget(REDIS_KEY, key)
@@ -46,3 +49,4 @@ redis_key = RedisKey(redis)
 
 if __name__ == '__main__':
     pass
+
